@@ -192,13 +192,21 @@ xsltLoadDocument(xsltTransformContextPtr ctxt, const xmlChar *URI) {
 	ret = ret->next;
     }
 
+#ifdef XSLT_PARSE_OPTIONS
+    doc = xmlReadFile((const char *) URI, NULL, ctxt->parserOptions);
+#else
     doc = xmlParseFile((const char *) URI);
+#endif
     if (doc == NULL)
 	return(NULL);
 
     if (ctxt->xinclude != 0) {
 #ifdef LIBXML_XINCLUDE_ENABLED
+#if LIBXML_VERSION >= 20603
+	xmlXIncludeProcessFlags(doc, ctxt->parserOptions);
+#else
 	xmlXIncludeProcess(doc);
+#endif
 #else
 	xsltTransformError(ctxt, NULL, NULL,
 	    "xsltLoadDocument(%s) : XInclude processing not compiled in\n",
@@ -210,7 +218,7 @@ xsltLoadDocument(xsltTransformContextPtr ctxt, const xmlChar *URI) {
      */
     if (xsltNeedElemSpaceHandling(ctxt))
 	xsltApplyStripSpaces(ctxt, xmlDocGetRootElement(doc));
-    if (xslDebugStatus == XSLT_DEBUG_NONE)
+    if (ctxt->debugStatus == XSLT_DEBUG_NONE)
 	xmlXPathOrderDocElems(doc);
 
     ret = xsltNewDocument(ctxt, doc);
@@ -262,7 +270,11 @@ xsltLoadStyleDocument(xsltStylesheetPtr style, const xmlChar *URI) {
 	ret = ret->next;
     }
 
+#ifdef XSLT_PARSE_OPTIONS
+    doc = xmlReadFile((const char *) URI, NULL, XSLT_PARSE_OPTIONS);
+#else
     doc = xmlParseFile((const char *) URI);
+#endif
     if (doc == NULL)
 	return(NULL);
 
