@@ -1,21 +1,22 @@
 /*
- * libxslt.h: internal header only used during the compilation of libxslt
+ * Summary: internal header only used during the compilation of libxslt
+ * Description: internal header only used during the compilation of libxslt
  *
- * See COPYRIGHT for the status of this software
+ * Copy: See Copyright for the status of this software.
  *
- * Author: daniel@veillard.com
+ * Author: Daniel Veillard
  */
 
 #ifndef __XSLT_LIBXSLT_H__
 #define __XSLT_LIBXSLT_H__
 
-#if defined(WIN32) && !defined (__CYGWIN__)
+#if defined(WIN32) && !defined (__CYGWIN__) && !defined (__MINGW32__)
 #include <win32config.h>
 #else
 #include "config.h"
 #endif
 
-#if defined(WIN32) && !defined(__CYGWIN__)
+#if defined(WIN32) && !defined(__CYGWIN__) && !defined (__MINGW32__)
 #include "xsltwin32config.h"
 #else
 #include "xsltconfig.h"
