@@ -574,8 +574,14 @@ xsltNumberFormatGetAnyLevel(xsltTransformContextPtr context,
 	if (count == NULL) {
 	    if ((node->type == cur->type) &&
 		/* FIXME: must use expanded-name instead of local name */
-		xmlStrEqual(node->name, cur->name))
-		cnt++;
+		xmlStrEqual(node->name, cur->name)) {
+		    if ((node->ns == cur->ns) ||
+		        ((node->ns != NULL) &&
+			 (cur->ns != NULL) &&
+		         (xmlStrEqual(node->ns->href,
+		             cur->ns->href) )))
+		        cnt++;
+	    }
 	} else {
 	    if (xsltTestCompMatchList(context, cur, countPat))
 		cnt++;
@@ -663,9 +669,14 @@ xsltNumberFormatGetMultipleLevel(xsltTransformContextPtr context,
 		        xmlXPathNextPrecedingSibling(parser, preceding)) {
 		    if (count == NULL) {
 			if ((preceding->type == ancestor->type) &&
-			    /* FIXME */
-			    xmlStrEqual(preceding->name, ancestor->name))
-			    cnt++;
+			    xmlStrEqual(preceding->name, ancestor->name)){
+			    if ((preceding->ns == ancestor->ns) ||
+			        ((preceding->ns != NULL) &&
+				 (ancestor->ns != NULL) &&
+			         (xmlStrEqual(preceding->ns->href,
+			             ancestor->ns->href) )))
+			        cnt++;
+			}
 		    } else {
 			if (xsltTestCompMatchList(context, preceding,
 				                  countPat))
